dystonia: Biomarkers of Cervical Dystonia (CD)

Description Usage Format

Description

Biomarkers of Cervical Dystonia (CD)

Usage

1

Format

A data frame of 2960 observations of 5 variables:

CD

A character variable coding for the presence of cervical dystonia (CD)

Group

A character variable coding for three levels: Control, Cervical Dystonia, and Cervical Dystonia with the addition of hypothyroidism

Assay

Biomarker name, as used in the literature

Sample

Participant code. Most biomarkers are measured twice for each participant

Biomarker Level

Numerical measurement of biomarker level


jlucasmckay/JLmisc documentation built on Dec. 14, 2019, 9:33 p.m.