Biomarkers of Cervical Dystonia (CD)
1 |
A data frame of 2960 observations of 5 variables:
A character variable coding for the presence of cervical dystonia (CD)
A character variable coding for three levels: Control, Cervical Dystonia, and Cervical Dystonia with the addition of hypothyroidism
Biomarker name, as used in the literature
Participant code. Most biomarkers are measured twice for each participant
Numerical measurement of biomarker level
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.